﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Hammer : MonoBehaviour
{

    [Header("Charge")]
    [SerializeField, Min(0.0f), Tooltip("How fast to rotate.")] 
    float rotationSpeed;

    [SerializeField, Min(0.0f), Tooltip("Maximum time the hammer can be rotating.")]
    float maxRotationTime;

    [SerializeField, Tooltip("Curve for rotation.")]
    AnimationCurve rotationCurve;

    [Header("Shake")]
    [SerializeField, Min(0.0f), Tooltip("How much to shake at maximum charge.")] 
    float maxShake;

    [SerializeField, Tooltip("Curve for shaking.")] 
    AnimationCurve shakeCurve;

    [Header("Strike")]
    [SerializeField, Min(0.0f), Tooltip("How long to achieve strike rotation when max charge.")]
    float minStrikeTime;

    [SerializeField, Min(0.0f), Tooltip("How long to achieve strike rotation when min charge.")]
    float maxStrikeTime;

    [SerializeField, Tooltip("Curve for strike time.")]
    AnimationCurve strikeCurve;

    float currentRotation;

    // This is called every frame while the player is holding input.
    public void ChargeHammer(float chargeTime)
    {
        if (chargeTime < maxRotationTime)
        {
            RotateHammer(chargeTime);
        }

        WobbleHammer(chargeTime);
    }

    void RotateHammer(float chargeTime)
    {
        float curveValue = rotationCurve.Evaluate(chargeTime / maxRotationTime);
        currentRotation = curveValue * rotationSpeed;
    }

    void WobbleHammer(float chargeTime)
    {
        float curveValue = rotationCurve.Evaluate(chargeTime / maxRotationTime);
        float shake = curveValue * maxShake;

        float newRotation = Random.Range(-shake, shake) + currentRotation;

        transform.rotation = Quaternion.Euler(10f, 0.0f, -99f);
        // end time
        transform.position = new Vector3(.8f, -3.5f, 0f);
    }

    public void StrikeHammer(float totalCharge)
    {
        float curveValue = strikeCurve.Evaluate(totalCharge / maxRotationTime);
        float strikeTime = Mathf.Lerp(minStrikeTime, maxStrikeTime, (1.0f - curveValue));

        iTween.RotateTo(gameObject, new Vector3(0.0f, 0.0f, -70f), strikeTime);
        // start time

    }

    public void OnTriggerEnter2D(Collider2D collider)
    {
        OnStrikeComplete();
    }

    void OnStrikeComplete()
    {

    }
}
